# OpenCOS Documentation

## Chapters

* [Installation](Installation.md)
* [Directory Structure](DirectoryStructure.md)
* [RTL Coding](RtlCodingStyle.md)
* [DEPS.yml](DEPS.md)
* [eda usage](eda.md)
* [Connecting Apps](ConnectingApps.md)
* [oc_vivado.tcl](OcVivadoTcl.md)
* [Open Questions](OpenQuestions.md)
* [Format Examples](format_examples/readme.md)
